pub fn list_locales() -> impl Iterator<Item = (DataLocale, TinyAsciiStr<8>)>Expand description
Lists the locale and collation keyword combinations that the collator knows about.
The standard collation is represented as the empty string.
The root collation is represented as und.
Chinese collations are listed as und-Hani with und-Hant and und-Hans resolving
to stroke and pinyin despite not listing the collation keyword.
The iterator may (in practice will) yield duplicate items.